==> kpackagekit_0.5.4.orig.tar.gz: kpackagekit-0.5.4/libkpackagekit/KpkSimplePackageModel.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Daniel Nicoletti                                *
 *   dantti85-pk@yahoo.com.br                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef KPK_SIMPLE_PACKAGE_MODEL_H
#define KPK_SIMPLE_PACKAGE_MODEL_H

#include <QStandardItemModel>
#include <KIcon>

#include <QPackageKit>

using namespace PackageKit;

class KDE_EXPORT KpkSimplePackageModel : public QStandardItemModel
{
Q_OBJECT

public:
    KpkSimplePackageModel(QObject *parent = 0);

public slots:
    void addPackage(PackageKit::Package *package);
    void addPackages(const QList<PackageKit::Package *> &pkgs);
};

#endif

==> kpackagekit_0.6.2.orig.tar.gz: kpackagekit-0.6.2/libkpackagekit/KpkSimplePackageModel.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Daniel Nicoletti                                *
 *   dantti85-pk@yahoo.com.br                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef KPK_SIMPLE_PACKAGE_MODEL_H
#define KPK_SIMPLE_PACKAGE_MODEL_H

#include <QStandardItemModel>
#include <KIcon>

#include <QPackageKit>

using namespace PackageKit;

class KDE_EXPORT KpkSimplePackageModel : public QStandardItemModel
{
Q_OBJECT

public:
    KpkSimplePackageModel(QObject *parent = 0);

public slots:
    void addPackage(QSharedPointer<PackageKit::Package> package);
};

#endif
